summary refs log tree commit diff stats
path: root/plugins/perl/perl.c
diff options
context:
space:
mode:
authorBerke Viktor <bviktor@hexchat.org>2012-07-26 20:53:59 +0200
committerBerke Viktor <bviktor@hexchat.org>2012-07-26 20:53:59 +0200
commitec301a5a5486898cb4d9854a56eb866f1b93f634 (patch)
treec0cec2f567df7e1f62fc0168b2fe3cc68c9d8954 /plugins/perl/perl.c
parent7f831646bb8c31966e0f3ff77d40ce66711daa99 (diff)
Auto-load user plugins and scripts from <config>/addons
On Unix leave $(libdir)/hexchat/plugins for plugin packagers, on Windows
prevent users from modifying Program Files by ignoring everything except
bundled plugins
Diffstat (limited to 'plugins/perl/perl.c')
-rw-r--r--plugins/perl/perl.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/plugins/perl/perl.c b/plugins/perl/perl.c
index 7eea9efb..c9bfa5e9 100644
--- a/plugins/perl/perl.c
+++ b/plugins/perl/perl.c
@@ -145,15 +145,15 @@ perl_auto_load (void *unused)
 		xdir = xchat_get_info (ph, "xchatdir");
 
 	/* don't pollute the filesystem with script files, this only causes misuse of the folders
 	 * only use ~/.config/hexchat/scripts/ and %APPDATA%\HexChat\scripts */
 #if 0
 	/* autoload from ~/.config/hexchat/ or %APPDATA%\HexChat\ on win32 */
 	perl_auto_load_from_path (xdir);
 #endif
 
-	sub_dir = malloc (strlen (xdir) + 9);
+	sub_dir = malloc (strlen (xdir) + 8);
 	strcpy (sub_dir, xdir);
-	strcat (sub_dir, "/scripts");
+	strcat (sub_dir, "/addons");
 	perl_auto_load_from_path (sub_dir);
 	free (sub_dir);
@@ -145,15 +145,15 @@ perl_auto_load (void *unused)
 
 	/* don't pollute the filesystem with script files, this only causes misuse of the folders
-	 * only use ~/.config/hexchat/scripts/ and %APPDATA%\HexChat\scripts */
+	 * only use ~/.config/hexchat/addons/ and %APPDATA%\HexChat\addons */
 #if 0
 	/* autoload from ~/.config/hexchat/ or %APPDATA%\HexChat\ on win32 */